@@ -47,7 +47,7 @@ Exception
         * 406 - HTTPNotAcceptable
         * 407 - HTTPProxyAuthenticationRequired
         * 408 - HTTPRequestTimeout
-        * 409 - HTTPConfict
+        * 409 - HTTPConflict
         * 410 - HTTPGone
         * 411 - HTTPLengthRequired
         * 412 - HTTPPreconditionFailed
@@ -82,6 +82,8 @@ except ImportError:
 import types
 from webob import Response, Request, html_escape
 
+newstyle_exceptions = issubclass(Exception, object)
+
 tag_re = re.compile(r'<.*?>', re.S)
 br_re = re.compile(r'<br.*?>', re.I|re.S)
 comment_re = re.compile(r'<!--|-->')
@@ -112,7 +114,7 @@ class HTTPException(Exception):
 
     def __init__(self, message, wsgi_response):
         Exception.__init__(self, message)
-        self.wsgi_response = wsgi_response
+        self.__dict__['wsgi_response'] = wsgi_response
 
     def __call__(self, environ, start_response):
         return self.wsgi_response(environ, start_response)
@@ -122,6 +124,20 @@ class HTTPException(Exception):
     
     exception = property(exception)
 
+    # for old style exceptions
+    if not newstyle_exceptions:
+        def __getattr__(self, attr):
+            if not attr.startswith('_'):
+                return getattr(self.wsgi_response, attr)
+            else:
+                raise AttributeError(attr)
+
+        def __setattr__(self, attr, value):
+            if attr.startswith('_') or attr in ('args',):
+                self.__dict__[attr] = value
+            else:
+                setattr(self.wsgi_response, attr, value)
+
 class WSGIHTTPException(Response, HTTPException):
 
     ## You should set in subclasses:
@@ -158,10 +174,10 @@ ${body}''')
     empty_body = False
 
     def __init__(self, detail=None, headers=None, comment=None,
-                 body_template=None):
+                 body_template=None, **kw):
         Response.__init__(self,
                           status='%s %s' % (self.code, self.title),
-                          content_type='text/html')
+                          content_type='text/html', **kw)
         Exception.__init__(self, detail)
         if headers:
             self.headers.update(headers)
@@ -170,6 +186,9 @@ ${body}''')
         if body_template is not None:
             self.body_template = body_template
             self.body_template_obj = Template(body_template)
+        if self.empty_body:
+            del self.content_type
+            del self.content_length
 
     def _make_body(self, environ, escape):
         args = {
@@ -234,7 +253,7 @@ ${body}''')
     wsgi_response = property(wsgi_response)
 
     def exception(self):
-        if sys.version_info >= (2, 5):
+        if newstyle_exceptions:
             return self
         else:
             return HTTPException(self.detail, self)
@@ -376,12 +395,11 @@ class HTTPNotModified(HTTPRedirection):
     empty_body = True
 
 class HTTPUseProxy(_HTTPMove):
-    # FIXME: Not a move, but looks a little like one
+    # Not a move, but looks a little like one
     code = 305
     title = 'Use Proxy'
     explanation = (
-        'The resource must be accessed through a proxy '
-        'located at ')
+        'The resource must be accessed through a proxy located at')
 
 class HTTPTemporaryRedirect(_HTTPMove):
     code = 307
